#R Script for running Wordscores and LDA models

#Set working directory (change to directory with word frequency matrices provided "summaries_ws.csv" and "summaries_lda.csv")
setwd("/CHANGE")

#Install necessary packages
install.packages("austin")
install.packages("topicmodels")

#Descriptive statistics about text length
rm(list=ls())
library(austin)
summaries_texts <- wfm("summaries_ws.csv", word.margin = 2)
summed_stems <- rowSums(summaries_texts[-c(1, 2), -c(1)]) 
#Produce TABLE A5 in the Web Appendix ----> Summary statistics on word length
summary(summed_stems)
write.table(summed_stems, file = "text_lengths.csv")

#Wordscores
rm(list=ls())
library(austin)
summaries_texts <- wfm("summaries_ws.csv", word.margin = 2)
ref <- getdocs(summaries_texts, c(1, 2))
scores <- classic.wordscores(ref, scores = c(1, -1))
vir <- getdocs(summaries_texts, -c(1, 2))
text_scores <- predict(scores, newdata = vir)
#Save information for TABLE A5 in the Web Appendix ----> Wordscores for each word
write.table(coef(scores), file ="ws_words.csv")
#Save information on Wordscores for each summary text (to be imported to STATA), compare example summaries at end of Web Appendix
write.table(text_scores, file ="ws_texts.csv")

#LDA
rm(list=ls())
library(topicmodels)
library(austin)
summaries_texts <- wfm("summaries_lda.csv", word.margin = 2)
#Delete very infrequent and very frequent words (occurring less than 0.5% or in more than 90% of summaries)
summaries_texts <- summaries_texts[ ,colSums(summaries_texts == 0)/nrow(summaries_texts) < 0.995 & colSums(summaries_texts == 0)/nrow(summaries_texts) > 0.1]
#LDA with 45 topics
lda <- LDA(summaries_texts, control=list(seed=0), k = 45, nstart = 1000)
terms <- terms(lda, 20)
topic <- topics(lda)
probability <- posterior(lda)
#Save information for parts of TABLE 3 in the Paper and TABLE A6 in the Web Appendix ----> 20 most frequent stems by topic
write.table(terms, file = "lda45final_terms.csv")
#Save information on most likely topic (to be imported to STATA)
write.table(topic, file = "lda45final_topic.csv")
#Save information on probability of each topic 
write.table(probability$topic, file = "lda45final_probabilities.csv")


